@@ -1,15 +1,13 @@
 package ExpenseTracker;
 {
-  $ExpenseTracker::VERSION = '0.008';
+  $ExpenseTracker::VERSION = '0.1';
 }
 {
-  $ExpenseTracker::VERSION = '0.008';
+  $ExpenseTracker::VERSION = '0.1';
 }
 use Mojo::Base 'Mojolicious';
 use ExpenseTracker::Models;
 use ExpenseTracker::Routes;
-use Mojolicious::Plugin::Authentication;
-use Digest::MD5 qw(md5 md5_hex);
 
 # ABSTRACT: Demo app for showing the synergy between perl and javascript
 
@@ -41,38 +39,14 @@ sub startup {
       }
     );
   }
-
-  $self->plugin(
-    'authentication' => {
-      'session_key' => 'wickedapp',
-      'load_user'   => sub {
-        my ( $app, $uid ) = @_;
-        my $schema = $self->app->model;                
-        return $schema->resultset('ExpenseTracker::Models::Result::User')->find($uid);          
-      },
-      'validate_user' => sub {
-        my ( $app, $username, $pass, $extra ) = @_;
-
-        my $schema = $self->app->model;
-        my $user =
-          $schema->resultset('ExpenseTracker::Models::Result::User')
-          ->search_rs( { username => $username, password => md5_hex($pass) } )
-          ->next();          
-        
-        $self->{uid} = $user->id() if defined($user);
-        return $self->{uid};
-      },
-    }
-  );
-
+  
   $self->hook(after_static_dispatch => sub {
     my $c = shift;
-
-    $self->{uid} = $c->session->{wickedapp};
-    $c->session->{_menu} = defined($c->app->user)
-                ? $c->app->{config}->{app_menu}->{regular}
+    
+    $c->session->{_menu} = defined($c->session->{user})
+                ? $c->app->{config}->{app_menu}->{$c->session->{user}->{user_type} }
                 : $c->app->{config}->{app_menu}->{anonymous} ;
-  });  
+   });  
    
   # Routes
   my $r = $self->routes;
@@ -80,21 +54,15 @@ sub startup {
   #set location for controllers
   $r->namespace('ExpenseTracker::Controllers');
   
-  $r->route('/')->to("site#welcome")->name('home');
-
-  #routes to user controller
-  $r->route('/login')->to('login#login')->name('login');
-  $r->route('/logout')->to('login#logout')->name('logout');
-  $r->route('/authenticate')->to('login#auth')->name('authenticate_html');
-
+  $r->route('/')->to("site#welcome");
+  
   my $api_routes = $r->route('/api')->over( authenticated => 1 );
 
   my $routes_params = {
     app_routes            => $r,
-    api_base_url          => $self->{config}->{api}->{base_url},
+    api_base_url          => '/api',
     controllers_namespace => 'ExpenseTracker::Controllers',
-    resource_names        => [ split ' ', $self->{config}->{expose_resources} ],
-    app                   => $self,
+    resource_names        => [ qw/category operation currency operations_category / ],
   };
   
   ExpenseTracker::Routes->create_routes( $routes_params );
@@ -103,9 +71,8 @@ sub startup {
 
 sub user{
   my $self = shift;
-  
-  return unless $self->{uid};
 
+  return unless $self->{uid};
   return $self->{user} if (defined($self->{user}) and $self->{user}->id() == $self->{uid} );
   $self->{user} = $self->model->resultset('User')->find( $self->{uid} );
   return $self->{user};
@@ -113,16 +80,3 @@ sub user{
 }
 
 1;
-
-__END__
-=pod
- 
-=head1 NAME
-ExpenseTracker - main app file
-
-
-=head1 VERSION
-
-version 0.008
-
-=cut
