@@ -1,12 +1,11 @@
 package ExpenseTracker::Controllers::Currency;
 {
-  $ExpenseTracker::Controllers::Currency::VERSION = '0.008';
+  $ExpenseTracker::Controllers::Currency::VERSION = '0.1';
 }
 {
-  $ExpenseTracker::Controllers::Currency::VERSION = '0.008';
+  $ExpenseTracker::Controllers::Currency::VERSION = '0.1';
 }
 use Mojo::Base 'ExpenseTracker::Controllers::Base';
-use DateTime;
 
 sub new{
   my $self = shift;
@@ -19,17 +18,4 @@ sub new{
   
 }
 
-1;
-
-__END__
-=pod
- 
-=head1 NAME
-ExpenseTracker::Controllers::Currency - Controller responsible for the Currency resource
-
-
-=head1 VERSION
-
-version 0.008
-
-=cut
+1;
\ No newline at end of file
